<?php

/**
 * ----------------------------------------------------------------
 * @Copyright   : License MIT 2016-2024
 * @WebSite     : https://www.shiros.fr
 *
 * @Author      : Alexandre Caillot
 *
 * @File        : SQLConnexionInterface.php
 * @Created_at  : 20/12/2021
 * @Update_at   : 09/11/2024
 * ----------------------------------------------------------------
 */

namespace Luna\SQL\Connexion;

use PDO;

interface SQLConnexionInterface
{
    # --------------------------------
    # Getters

    /**
     * Init SQL connexion system.
     * Established the connexion to Sql Database using PDO.
     *
     * Usage :
     * ```
     * // Get the manager
     * $manager = ...;
     *
     * // Initialize the connexion
     * $manager->init();
     *
     * // At this point, the PDO instance is available.
     * ```
     *
     * @return static
     */
    public function init(): static;

    /**
     * Close SQL connexion.
     *
     * Usage :
     * ```
     * // Get the manager
     * $manager = ...;
     *
     * // Close the connexion
     * $manager->close();
     *
     * // At this point, the PDO connexion is closed
     * ```
     *
     * @return static
     */
    public function close(): static;

    # --------------------------------
    # Getters

    /**
     * Get SQL connexion.
     *
     * Usage :
     * ```
     * // Get the manager
     * $manager = ...;
     *
     * // Get the SQL connexion (PDO instance)
     * $connexion = $manager->getConnexion();
     * ```
     *
     * @return PDO
     */
    public function getConnexion(): PDO;
}
