<?php

/**
 * ----------------------------------------------------------------
 * @Copyright   : License MIT 2016-2024
 * @WebSite     : https://www.shiros.fr
 *
 * @Author      : Alexandre Caillot
 *
 * @File        : SQLManagerModule.php
 * @Created_at  : 26/08/2023
 * @Update_at   : 21/12/2024
 * ----------------------------------------------------------------
 */

namespace Luna\SQL\DI\Module;

use Luna\Component\Bag\ReadOnlyBag;
use Luna\Component\Container\Exception\ContainerException;
use Luna\Component\DI\Module\AbstractModule;
use Luna\Component\DI\Processor\ModuleProcessor;
use Luna\SQL\Manager\Resolver\SQLManagerResolver;
use Luna\SQL\Manager\SQLManagerInterface;

class SQLManagerModule extends AbstractModule
{
    # --------------------------------
    # Core methods

    /**
     * @inheritDoc
     *
     * Get the SQL manager.
     *
     * @return SQLManagerInterface
     * @throws ContainerException
     */
    public function process(ReadOnlyBag $arguments, ModuleProcessor $moduleProcessor): SQLManagerInterface
    {
        // ----------------
        // Process

        // Get the resolver
        $resolver = new SQLManagerResolver(
            container: $this->container
        );

        // Resolve the SQL manager
        return $resolver->resolve();
    }
}
