<?php

/**
 * --------------------------------------------------------------------------
 * @Copyright   : License MIT 2016-2024
 * @WebSite     : https://www.shiros.fr
 *
 * @Author      : Alexandre Caillot
 *
 * @File        : Module.php
 * @Created_at  : 06/11/2024
 * @Update_at   : 25/11/2024
 * --------------------------------------------------------------------------
 */

namespace Luna\SQL;

use Luna\Component\Container\Exception\ContainerException;
use Luna\Component\File\Exception\Writer\FileWriterException;
use Luna\Component\Lock\Entity\LockModule;
use Luna\Component\Manager\PathManager;
use Luna\Component\Module\AbstractModule;
use Luna\SQL\Constant\SQLConstant;
use Luna\SQL\Manager\SQLManager;

class Module extends AbstractModule
{
    # --------------------------------
    # Life-Cycle methods

    /**
     * @inheritDoc
     *
     * @throws ContainerException
     * @throws FileWriterException
     */
    public function install(LockModule $module): void
    {
        // ----------------
        // Vars

        // Get information
        $appDir = $this->getAppDir();

        // ----------------
        // Process

        // Copy files
        $this
            ->copyConfig(directory: $appDir)
        ;
    }

    # --------------------------------
    # Core methods

    /**
     * @inheritDoc
     *
     * @throws ContainerException
     */
    public function boot(): void
    {
        // ----------------
        // Vars

        // Get information
        $config = $this
            ->getContainer()
            ->getConfig()
        ;

        // Paths
        $moduleDir = $this->getRootDir();
        $configDir = PathManager::sanitize("{$moduleDir}/config");

        // ----------------
        // Process

        // Generate SQL components
        $sqlManager = new SQLManager();

        // Set SQL components in the container
        $this
            ->getContainer()
            ->set(SQLConstant::CONTAINER_SQL_MANAGER, $sqlManager)
        ;

        // Register module configuration
        $config->load(path: $configDir);
    }

    # --------------------------------
    # Utils methods

    /**
     * Copy SQL config in the application folder.
     *
     * @param string $directory
     *
     * @return self
     * @throws FileWriterException
     */
    protected function copyConfig(
        string $directory
    ): self {
        // ----------------
        // Vars

        // Get information
        $moduleDir    = $this->getRootDir();
        $config       = PathManager::sanitize(path: "{$moduleDir}/config/storage/sql");
        $appConfigDir = PathManager::sanitize(path: "{$directory}/config/storage");

        // ----------------
        // Vars

        // Create SQL configuration
        return $this->copyConfigFile(
            source     : $config,
            destination: $appConfigDir
        );
    }
}
