<?php

/**
 * ----------------------------------------------------------------
 * @Copyright   : License MIT 2016-2024
 * @WebSite     : https://www.shiros.fr
 *
 * @Author      : Alexandre Caillot
 *
 * @File        : AbstractSQLRepository.php
 * @Created_at  : 18/12/2021
 * @Update_at   : 17/12/2024
 * ----------------------------------------------------------------
 */

namespace Luna\SQL\Repository;

use Luna\Component\Bag\BagInterface;
use Luna\SQL\Connexion\SQLConnexionInterface;
use Luna\SQL\Manager\Exception\SQLManagerResolverException;
use Luna\SQL\Manager\SQLManagerInterface;

abstract class AbstractSQLRepository implements SQLRepositoryInterface
{
    # --------------------------------
    # Attributes

    /**
     * SQL manager.
     * It allows you to access and execute actions in a SQL database.
     */
    protected SQLManagerInterface $manager;

    # --------------------------------
    # Constructor

    /**
     * AbstractSQLRepository constructor.
     *
     * @param SQLManagerInterface $manager
     */
    public function __construct(SQLManagerInterface $manager)
    {
        // Set attributes
        $this->manager = $manager;
    }

    # --------------------------------
    # Core methods

    /**
     * @inheritDoc
     *
     * @throws SQLManagerResolverException
     */
    public function execute(
        SQLConnexionInterface|string $connexion,
        BagInterface|array|string    $query,
        BagInterface|array           $variables = [],
        BagInterface|array           $options = [],
        ?int                         &$status = null
    ): mixed {
        // ----------------
        // Process

        // Execute the query
        return $this->manager->execute(
            connexion: $connexion,
            query    : $query,
            variables: $variables,
            options  : $options,
            status   : $status
        );
    }
}
