<?php

/**
 * ----------------------------------------------------------------
 * @Copyright   : License MIT 2016-2024
 * @WebSite     : https://www.shiros.fr
 *
 * @Author      : Alexandre Caillot
 *
 * @File        : SQLRepositoryInterface.php
 * @Created_at  : 21/12/2021
 * @Update_at   : 09/11/2024
 * ----------------------------------------------------------------
 */

namespace Luna\SQL\Repository;

use Luna\Component\Bag\BagInterface;
use Luna\SQL\Connexion\SQLConnexionInterface;

interface SQLRepositoryInterface
{
    # --------------------------------
    # Core methods

    /**
     * Execute an SQL query in a specific connexion.
     *
     * Parameters :
     * - Connexion  : SQL Connexion or the connexion key
     * - Query      : SQL query
     * - Variables  : SQL query variables
     * - Options    : SQL query options
     * - Status     : Execute status
     *
     * @param SQLConnexionInterface|string $connexion
     * @param BagInterface|array|string    $query
     * @param BagInterface|array           $variables
     * @param BagInterface|array           $options
     * @param int|null                     $status
     *
     * @return mixed
     */
    public function execute(
        SQLConnexionInterface|string $connexion,
        BagInterface|array|string    $query,
        BagInterface|array           $variables = [],
        BagInterface|array           $options = [],
        ?int                         &$status = null
    ): mixed;
}
