<?php

/**
 * ----------------------------------------------------------------
 * @Copyright   : License MIT 2016-2024
 * @WebSite     : https://www.shiros.fr
 *
 * @Author      : Alexandre Caillot
 *
 * @File        : SQLTransaction.php
 * @Created_at  : 20/12/2021
 * @Update_at   : 09/11/2024
 * ----------------------------------------------------------------
 */

namespace Luna\SQL\Transaction;

interface SQLTransactionInterface
{
    # --------------------------------
    # Constant

    /**
     * Defines whether the transaction should be active.
     */
    public const OPTION_ENABLE = 'enable';

    # --------------------------------
    # Core methods

    /**
     * Start a database transaction.
     *
     * @return void
     */
    public function begin(): void;

    /**
     * Rollback a database transaction.
     *
     * @return void
     */
    public function rollback(): void;

    /**
     * Verify if the process is in a database transaction.
     *
     * @return bool
     */
    public function hasIn(): bool;

    /**
     * Commit a database transaction.
     *
     * @return void
     */
    public function commit(): void;
}
